summaryrefslogtreecommitdiff
path: root/spec/ruby/library/readline/spec_helper.rb
diff options
context:
space:
mode:
Diffstat (limited to 'spec/ruby/library/readline/spec_helper.rb')
-rw-r--r--spec/ruby/library/readline/spec_helper.rb6
1 files changed, 3 insertions, 3 deletions
diff --git a/spec/ruby/library/readline/spec_helper.rb b/spec/ruby/library/readline/spec_helper.rb
index 04ab0f755f..32d820f7ac 100644
--- a/spec/ruby/library/readline/spec_helper.rb
+++ b/spec/ruby/library/readline/spec_helper.rb
@@ -1,11 +1,11 @@
-require File.expand_path('../../../spec_helper', __FILE__)
+require_relative '../../spec_helper'
begin
require 'readline'
rescue LoadError
else
- # rb-readline behaves quite differently
- unless defined?(RbReadline)
+ # rb-readline and reline behave quite differently
+ unless defined?(RbReadline) or defined?(Reline)
MSpec.enable_feature :readline
end
end